<?php
	class SrpluginsHelper {
		static function getBackupDirectory() {
			return get_home_path().'wp-content/srcmehranclub_backups/';
		}

		static function getDownloadDirectory() {
			return get_home_path().'wp-content/srcmehranclub_downloads/';
		}

		static function getDownloadUrl() {
			return get_home_url().'/wp-content/srcmehranclub_downloads/';
		}

		static function getBackupUrl() {
			return get_home_url().'/wp-content/srcmehranclub_backups/';
		}

		static function zip($source, $destination){
		  if (!extension_loaded('zip') || !file_exists($source)) {
		    return false;
		  }
		 
		  $zip = new ZipArchive();
		  if (!$zip->open($destination, ZIPARCHIVE::CREATE)) {
		    return false;
		  }
		 
		  $source = str_replace('\\', '/', realpath($source));

		  if (is_dir($source) === true){
		  	$firstDir = @end(explode('/', $source));
		  	$zip->addEmptyDir($firstDir . '/');
		    $files = new RecursiveIteratorIterator(new RecursiveDirectoryIterator($source), RecursiveIteratorIterator::SELF_FIRST);
		 	
		    foreach ($files as $file){
		        $file = str_replace('\\', '/', $file);
		 
		        // Ignore "." and ".." folders
		        if( in_array(substr($file, strrpos($file, '/')+1), array('.', '..')) )
		            continue;
		 
		        $file = realpath($file);
		        $file = str_replace('\\', '/', $file);
		         
		        if (is_dir($file) === true){
		            $zip->addEmptyDir(str_replace($source . '/', $firstDir . '/', $file . '/'));
		        }else if (is_file($file) === true){
		            $zip->addFromString(str_replace($source . '/', $firstDir . '/', $file), file_get_contents($file));
		        }
		    }
		  }else if (is_file($source) === true){
		    $zip->addFromString(basename($source), file_get_contents($source));
		  }
		  return $zip->close();
		}

	    static function rcopy($src, $dst) {
	        if (file_exists ( $dst ))
	            self::rrmdir ( $dst );
	        if (is_dir ( $src )) {
	            mkdir ( $dst );
	            $files = scandir ( $src );
	            foreach ( $files as $file )
	                if ($file != "." && $file != "..")
	                    self::rcopy ( "$src/$file", "$dst/$file" );
	        } else if (file_exists ( $src ))
	            copy ( $src, $dst );
	    }

	    static function rrmdir($dir) {

	        if (is_dir($dir)) {
	            $files = scandir($dir);
	            foreach ($files as $file)
	                if ($file != "." && $file != "..") self::rrmdir("$dir/$file");
	            rmdir($dir);
	        }
	        else if (file_exists($dir)) unlink($dir);
	    }

		static function setCredentials($key, $secret){
			update_option('srclubplugins_credentials', json_encode(array('key' => $key, 'secret' => $secret)));
		}

		static function getCredentials(){
			return json_decode(get_option('srclubplugins_credentials'), true);
		}

		static function getDirectorySize($dir){
			$size = 0;

			foreach (glob(rtrim($dir, '/').'/*', GLOB_NOSORT) as $each) {
				$size += is_file($each) ? filesize($each) : self::getDirectorySize($each);
			}
			return self::formatSize($size);
		}

		static function getInstalledProductByName($name, $type){
			switch($type){
				case 'plugin':
					$plugins = get_plugins();

					foreach($plugins as $idx => $p){
						if($p['Name'] == $name){
							$p['file'] = /*get_home_path().'wp-content/plugins/'.*/$idx;
							return $p;
						}
					}
				break;
				case 'theme':
					$themes = wp_get_themes();

					foreach($themes as $idx => $p){
						if($p['Name'] == $name){
							$p['file'] = /*get_home_path().'wp-content/plugins/'.*/$idx;
							return $p;
						}
					}
				break;
			}

			return false;
		}

		static function formatSize($size){
			if($size < 1024){
				return $size.' bytes';
			} elseif($size < 1024*1024){
				return round($size/1024, 2).' KB';
			} elseif($size < 1024*1024*1024){
				return round($size/1024/1024, 2).' MB';
			}
		}

		static function send_request($data){
			if($curl = curl_init()){

				$creds = self::getCredentials();
				$data['key'] = $creds['key'];
				$data['secret'] = $creds['secret'];

				curl_setopt($curl, CURLOPT_URL, 'https://srmehranclub.com/wp-content/plugins/plugins_updater_api/api.php');
				curl_setopt($curl,CURLOPT_USERAGENT,'Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13');
				curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
				curl_setopt($curl, CURLOPT_POST, 1);
				curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($data));
				$html = curl_exec($curl);
				curl_close($curl);

				return $html;
			}

			return false;
		}

		static function getProducts(){
			return json_decode(self::send_request(array('action' => 'products')), true);
		}

		static function getMeta(){
			return json_decode(self::send_request(array('action' => 'meta')), true);
		}

		static function getProduct($id){
			return json_decode(self::send_request(array('action' => 'product', 'id' => $id)), true);
		}

		static function downloadProduct($id, $path, $isUpdate = false, $domain = false){
			$post = array('action' => 'download', 'id' => $id);

			if($isUpdate){
				$post['update'] = true;
				$post['domain'] = $domain;
			}

			if($ret = self::send_request($post)){
				file_put_contents($path, $ret);
				return true;
			}

			return false;
		}
	}
?>