<?php
/*
    Plugin Name: srmehranclub.com plugins
    Description: Install and update plugins from srmehranclub.com
    Version: 0.1
    Author: SrmehranClub
    Author URI: https://srmehranclub.com/
*/

global $wpdb;
include( dirname(__FILE__) . '/helper.php' );
include( dirname(__FILE__) . '/pages.php' );

register_activation_hook(__FILE__, 'srclubplugins_plugin_activation');
register_deactivation_hook(__FILE__, 'srclubplugins_plugin_deactivation');

add_action('admin_menu', 'srclubplugins_admin_generate_menu');

function srclubplugins_script_enqueue($hook) {
    wp_enqueue_script('srclubplugins_script', plugin_dir_url(__FILE__) . 'js/init.js');
    wp_enqueue_style('srclubplugins_style', plugin_dir_url(__FILE__) . 'css/common.css');
}

add_action('admin_enqueue_scripts', 'srclubplugins_script_enqueue');

if ( !wp_next_scheduled( 'srclubplugins_hook' ) ) {
    wp_schedule_event( time(), 'daily', 'srclubplugins_hook' );
}

add_action( 'srclubplugins_hook', 'srclubplugins_upgrader' );


function srclubplugins_upgrader(){
        global $wpdb;
        $products = SrpluginsHelper::getProducts();
        foreach($products['data'] as $product){
            $p = SrpluginsHelper::getInstalledProductByName($product['product_name'], $product['type']);
            if($p){
                $version = ($product['type'] == 'plugin') ? $p['Version'] : $p->get('Version');
                $productId = $product['id'];

                if(version_compare($version, $product['version'], '<')){
                    if(($ret = SrpluginsHelper::getProduct($productId)) && $ret['status'] == 'success'){
                        $filepath = SrpluginsHelper::getDownloadDirectory() . $ret['data']['basename'];
                        $result = SrpluginsHelper::downloadProduct($productId, $filepath, true, $_SERVER['SERVER_NAME']);

                        if($result){

                            $historyDownload = array(
                                'type' => $product['type'],
                                'action' => 'download',
                                'version' => $product['version'],
                                'date' => date('Y-m-d H:i:s'),
                                'path' => $filepath,
                                'product_name' => $product['product_name']
                            );
                            $wpdb->insert($wpdb->prefix.'srclubplugins_history', $historyDownload);
                            
                            $isPlugin = ($historyDownload['type'] == 'plugin');
                            $dir = SrpluginsHelper::getDownloadDirectory();
                            $pluginRootDir = get_home_path().'wp-content/'.(($isPlugin) ? 'plugins' : 'themes').'/';
                            echo '<br><br><div>';
                            echo "<p>Create temp folder...<br></p>";
                            mkdir($dir.'temp/');

                            echo "<p>Extract from archive ".(($isPlugin) ? 'plugin' : 'theme')."...<br></p>";
                            echo "<p>Opening ".$historyDownload['path']."...<br></p>";


                            $zip = new ZipArchive; 
                            $zip->open($historyDownload['path']); 
                            $zip->extractTo($dir.'temp/'); 
                            $zip->close();
                            $pluginDirectory = @reset(array_diff(scandir($dir.'temp/'), array('.', '..')));
                            echo "<p>Move folder `$pluginDirectory`...<br></p>";

                            if(file_exists($pluginRootDir.$pluginDirectory)){
                                echo "<p>Сreate a backup copy of the previously installed ".(($isPlugin) ? 'plugin' : 'theme')."...<br></p>";
                                $backupFilename = $pluginDirectory.'-'.date('Y-m-d-His').'.zip';
                                $dirBackup = SrpluginsHelper::getBackupDirectory();
                                SrpluginsHelper::zip($pluginRootDir.$pluginDirectory, $dirBackup.$backupFilename);
                                $installedProduct = SrpluginsHelper::getInstalledProductByName($historyDownload['product_name'], $historyDownload['type']);
                                $history = array(
                                    'type' => $historyDownload['type'],
                                    'action' => 'backup',
                                    'version' => $installedProduct['Version'],
                                    'date' => date('Y-m-d H:i:s'),
                                    'path' => $dirBackup.$backupFilename,
                                    'product_name' => $historyDownload['product_name']
                                );
                                $wpdb->insert($wpdb->prefix.'srclubplugins_history', $history);
                            }



if(!empty($pluginDirectory))
SrpluginsHelper::rcopy($dir.'temp/'.$pluginDirectory, $pluginRootDir.$pluginDirectory);
else
echo "Tried to erase $pluginRootDir !!";

                            echo "<p>Clear temp folder...<br></p>";


                            echo "<p>Clear temp folder...<br></p>";
                            

SrpluginsHelper::rrmdir($dir.'temp/');
                            echo "<p>".(($isPlugin) ? 'Plugin' : 'Theme')." installed!<br></p>";
                            echo '</div>';

                        }
                    }
                }
            }
        }

}

function srclubplugins_plugin_activation()
{
    global $wpdb;

    SrpluginsHelper::setCredentials('','');

    if(!file_exists(SrpluginsHelper::getBackupDirectory())){
        mkdir(SrpluginsHelper::getBackupDirectory());
    }

    if(!file_exists(SrpluginsHelper::getDownloadDirectory())){
        mkdir(SrpluginsHelper::getDownloadDirectory());
    }

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

    dbDelta("CREATE TABLE IF NOT EXISTS `" . $wpdb->prefix . "srclubplugins_history` (
        `id` bigint(21) unsigned NOT NULL AUTO_INCREMENT,
        `type` VARCHAR(20) NOT NULL ,
        `action` VARCHAR(20) NOT NULL ,
        `version` VARCHAR(20) NOT NULL ,
        `date` VARCHAR(19) NOT NULL ,
        `path` VARCHAR(200) NOT NULL ,
        `product_name` VARCHAR(100) NOT NULL ,
        PRIMARY KEY (`id`),
        UNIQUE KEY `id` (`id`)
    ) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1");
}

function srclubplugins_plugin_deactivation()
{
    global $wpdb;

    delete_option('srclubplugins_credentials');
}

function srclubplugins_admin_generate_menu()
{
    add_menu_page('SrmehranСlub Plugins', 'SrmehranСlub Plugins', 'manage_options', 'srclubplugins', 'srclubplugins_plugins', 'dashicons-admin-plugins');
    add_submenu_page('srclubplugins', 'Plugins', 'Plugins', 'manage_options', 'srclubplugins', 'srclubplugins_plugins');
    add_submenu_page('srclubplugins', 'Files', 'Files', 'manage_options', 'srclubplugins-files', 'srclubplugins_files');
    add_submenu_page('srclubplugins', 'Settings', 'Settings', 'manage_options', 'srclubplugins-settings', 'srclubplugins_settings');
}

function srclubplugins_settings()
{
    srclubplugins_page_settings();
}

function srclubplugins_plugins()
{
    srclubplugins_page_plugins();
}

function srclubplugins_files()
{
    srclubplugins_page_files();
}